@@ -6,10 +6,11 @@ soilDB.env <- new.env(hash = TRUE)
 # safely register some options at package load time
 .onLoad <- function(libname, pkgname) {
   
-  # function verbosity
-  options(soilDB.verbose = FALSE,
-          soilDB.timeout = 300,
-          soilDB.ssl_verifyhost = 0)
+  # soilDB package options
+  options(soilDB.verbose = getOption("soilDB.verbose", default = FALSE),
+          soilDB.timeout = getOption("soilDB.timeout", default = 300),
+          soilDB.ssl_verifyhost = getOption("soilDB.ssl_verifyhost", default = 0),
+          soilDB.warn.aliases = getOption("soilDB.warn.aliases", default = TRUE))
   
   # set default local nasis authentication
   options(soilDB.NASIS.credentials = "DSN=nasis_local;UID=NasisSqlRO;PWD=nasisRe@d0n1y")
@@ -78,3 +79,24 @@ get_soilDB_env <- function() {
   unlink(tf)
   res
 }
+
+.soilDB_warn_deprecated_aliases <- function(aliases, FUN = deparse(sys.calls()[[sys.nframe() - 1]][[1]])) {
+  if (.soilDB_warn_deprecated(FUN) && length(aliases) > 0) {
+    message("------------------------------------------")
+    message("NOTE: `", FUN, "()` column aliases will be removed in the next minor soilDB release (2.9.x).")
+    message("Please replace use of the following column names with NASIS physical column name:")
+    sapply(seq(aliases), function(i) message("\t - ", aliases[i], " => ", names(aliases)[i]))
+    message("Set `options(soilDB.warn.aliases=FALSE)` to prevent this message from displaying in future sessions.")
+    message("See <https://ncss-tech.github.io/AQP/soilDB/bulletins/2025.01-1-soilDB-NASIS-column-aliases.html> for details.")
+    message("------------------------------------------")
+  }
+}
+
+.soilDB_warn_deprecated <- function(x) {
+  if (isFALSE(getOption("soilDB.warn.aliases", default = TRUE)) || x %in% soilDB.env$soilDB.warn.aliases_fnlist) {
+    return(FALSE)
+  } else {
+    soilDB.env$soilDB.warn.aliases_fnlist <- c(unique(soilDB.env$soilDB.warn.aliases_fnlist), x)
+    return(TRUE)
+  }
+}
