@@ -6,9 +6,6 @@
 #' Fetch KSSL laboratory pedon/horizon layer data from a local NASIS database,
 #' return as a SoilProfileCollection object.
 #'
-#' This function currently works only on Windows, and requires a 'nasis_local'
-#' ODBC connection.
-#'
 #' @param SS fetch data from the currently loaded selected set in NASIS or from
 #' the entire local database (default: `TRUE`)#'
 #' @param dsn Optional: path to local SQLite database containing NASIS
@@ -41,8 +38,8 @@ fetchNASISLabData <- function(SS = TRUE, dsn = NULL) {
 	# replace missing lower boundaries
 	missing.lower.depth.idx <- which(!is.na(h$hzdept) & is.na(h$hzdepb))
   if (length(missing.lower.depth.idx) > 0) {
-    message(paste('replacing missing lower horizon depths with top depth + 1cm ... [',
-                  length(missing.lower.depth.idx), ' horizons]', sep = ''))
+    message(paste0('replacing missing lower horizon depths with top depth + 1cm ... [',
+                  length(missing.lower.depth.idx), ' horizons]'))
     h$hzdepb[missing.lower.depth.idx] <- h$hzdept[missing.lower.depth.idx] + 1
   }
 
