@@ -28,7 +28,7 @@
     return(data.frame())
 
   # toggle selected set vs. local DB
-  if (SS == FALSE) {
+  if (isFALSE(SS)) {
     q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
   }
 
@@ -50,7 +50,7 @@
   if (length(idx) > 0) {
     message(paste("NOTICE: multiple records per pedon horizon exist in the `phlabresults` table, computing weighted averages and dominant values based on sample thickness"))
     
-    if (any(is.na(d.phlabresults[idx, "sampledepthbottom"]))) {
+    if (anyNA(d.phlabresults[idx, "sampledepthbottom"])) {
       message("NOTICE: some `phlabresults` records are missing `sampledepthbottom`; affected weighted averages will return `NA` and dominant values will be from the first (shallowest top depth) record per horizon")
     }
   
