@@ -119,7 +119,7 @@ ORDER BY siteobs_View_1.siteobsiid;")
     return(data.frame())
 
 	# toggle selected set vs. local DB
-	if (SS == FALSE) {
+	if (isFALSE(SS)) {
 	  q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
 	  q2 <- gsub(pattern = '_View_1', replacement = '', x = q2, fixed = TRUE)
 	  q3 <- gsub(pattern = '_View_1', replacement = '', x = q3, fixed = TRUE)
@@ -162,7 +162,7 @@ ORDER BY siteobs_View_1.siteobsiid;")
 	if (nrow(d) > 0) {
   	ldx <- !d$siteobsiid %in% phs$siteobsiid
   	if (!any(ldx)) {
-  	  phs <- phs[1:nrow(d),]
+  	  phs <- phs[seq_len(nrow(d)),]
   	  phs$siteobsiid <- d$siteobsiid
   	} else {
   	  phs_null <- phs[0,][1:sum(ldx),]
@@ -265,7 +265,7 @@ get_site_association_from_NASIS <- function(SS = TRUE, dsn = NULL) {
          LEFT OUTER JOIN site_View_1 s ON s.siteiid = sas.siteiidref"
       
   # toggle selected set vs. local DB
-  if (SS == FALSE) {
+  if (isFALSE(SS)) {
     q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
   }
   
