@@ -60,7 +60,7 @@ siblings <- function(s, only.major = FALSE, component.data = FALSE, cousins = FA
       if (inherits(sib, 'data.frame')) {
         
         # convert 'Yes'|'No' -> TRUE|FALSE
-        sib$majcompflag <- ifelse(sib$majcompflag == 'Yes', TRUE, FALSE)
+        sib$majcompflag <- sib$majcompflag == 'Yes'
         
         # note: there may be both major and minor siblings
         # optionally cut-down to just major siblings
