@@ -60,10 +60,10 @@ test_that("fetchNASIS(from='pedons') returns reasonable data", {
 
   # expected outcomes
   expect_true(inherits(x, 'SoilProfileCollection'))
-  expect_gt(nrow(site(x)), 0)
-  expect_gt(nrow(horizons(x)), 0)
-  expect_equivalent(idname(x), 'peiid')
-  expect_equivalent(horizonDepths(x), c("hzdept", "hzdepb"))
+  expect_gt(nrow(aqp::site(x)), 0)
+  expect_gt(nrow(aqp::horizons(x)), 0)
+  expect_equivalent(aqp::idname(x), 'peiid')
+  expect_equivalent(aqp::horizonDepths(x), c("hzdept", "hzdepb"))
 
   # no NA in total fragments using default arguments
   expect_false(anyNA(x$total_frags_pct))
@@ -94,8 +94,8 @@ test_that("fetchNASIS(from='pedons') nullFragsAreZero works as expected", {
   y <- suppressWarnings(fetchNASIS(from = 'pedons', nullFragsAreZero = FALSE))
 
   # no NA in total fragments using default arguments
-  expect_true(all(horizons(x)[is.na(y$total_frags_pct),'total_frags_pct'] == 0))
-  expect_true(all(horizons(x)[is.na(y$total_art_pct),'total_art_pct'] == 0))
+  expect_true(all(aqp::horizons(x)[is.na(y$total_frags_pct),'total_frags_pct'] == 0))
+  expect_true(all(aqp::horizons(x)[is.na(y$total_art_pct),'total_art_pct'] == 0))
 })
 
 test_that("fetchNASIS(from='components') returns reasonable data", {
@@ -115,10 +115,10 @@ test_that("fetchNASIS(from='components') returns reasonable data", {
 
   # expected outcomes
   expect_true(inherits(x, 'SoilProfileCollection'))
-  expect_gt(nrow(site(x)), 0)
-  expect_gt(nrow(horizons(x)), 0)
-  expect_equivalent(idname(x), 'coiid')
-  expect_equivalent(horizonDepths(x), c("hzdept_r", "hzdepb_r"))
+  expect_gt(nrow(aqp::site(x)), 0)
+  expect_gt(nrow(aqp::horizons(x)), 0)
+  expect_equivalent(aqp::idname(x), 'coiid')
+  expect_equivalent(aqp::horizonDepths(x), c("hzdept_r", "hzdepb_r"))
 
 })
 
