@@ -63,17 +63,17 @@ test_that("simplifyColorData: single color / moisture state / horizon", {
   res <- simplifyColorData(x.simple, id.var = 'phiid', wt = 'pct')
   
   # should be a single row
-  expect_equal(nrow(res), 1)
+  expect_equivalent(nrow(res), 1)
 
   # check parsing / conversion of dry color
-  expect_equal(res$d_r, res.rgb$r[1])
-  expect_equal(res$d_g, res.rgb$g[1])
-  expect_equal(res$d_b, res.rgb$b[1])
+  expect_equivalent(res$d_r, res.rgb$r[1])
+  expect_equivalent(res$d_g, res.rgb$g[1])
+  expect_equivalent(res$d_b, res.rgb$b[1])
 
   # check parsing / conversion of moist color
-  expect_equal(res$m_r, res.rgb$r[2])
-  expect_equal(res$m_g, res.rgb$g[2])
-  expect_equal(res$m_b, res.rgb$b[2])
+  expect_equivalent(res$m_r, res.rgb$r[2])
+  expect_equivalent(res$m_g, res.rgb$g[2])
+  expect_equivalent(res$m_b, res.rgb$b[2])
 
 })
 
@@ -90,7 +90,7 @@ test_that("simplifyColorData: two colors / moisture state, color percentages pro
   })
 
   # should be 2 rows
-  expect_equal(nrow(res), 2)
+  expect_equivalent(nrow(res), 2)
 
   # check dry color mixture, should be ~ 2.5Y 6/2
   # using wide tolerance, because changes in the Munsell LUT can create errors
@@ -122,7 +122,7 @@ test_that("simplifyColorData: missing data", {
   })
 
   # should be 2 rows
-  expect_equal(nrow(res), 2)
+  expect_equivalent(nrow(res), 2)
 
   # using wide tolerance, because changes in the Munsell LUT can create errors
 
@@ -145,19 +145,19 @@ test_that(".dominantColors: missing data", {
   res <- .dominantColors(x.missing)
 
   # should be 2 rows
-  expect_equal(nrow(res), 2)
+  expect_equivalent(nrow(res), 2)
 
   # dry color dominant should be 2.5Y 6/1 (75%)
   idx1 <- which(res$phiid == "2889133")
-  expect_equal(res$d_hue[idx1], '2.5Y')
-  expect_equal(res$d_value[idx1], 6)
-  expect_equal(res$d_chroma[idx1], 1)
+  expect_equivalent(res$d_hue[idx1], '2.5Y')
+  expect_equivalent(res$d_value[idx1], 6)
+  expect_equivalent(res$d_chroma[idx1], 1)
 
   # moist color dominant should be 10YR 5/6 (80%)
   idx2 <- which(res$phiid == "2889103")
-  expect_equal(res$m_hue[idx2], '10YR')
-  expect_equal(res$m_value[idx2], 5)
-  expect_equal(res$m_chroma[idx2], 6)
+  expect_equivalent(res$m_hue[idx2], '10YR')
+  expect_equivalent(res$m_value[idx2], 5)
+  expect_equivalent(res$m_chroma[idx2], 6)
 
 })
 
